@@ -1218,6 +1218,13 @@ class TestingGroup(object):
         self._parse_xml()
         self._init_codes()
 
+    @property
+    def method_fullname(self):
+        """Returns the full module.method name of the executable that this
+        group decorates.
+        """
+        return "{}.{}".format(self.element.module.name, self.element.name)
+
     @property
     def name(self):
         """Returns the name of the underlying DocGroup."""
